// Copyright (C) 2005-2007 Stefan Bauer <yoltia-maintain@freenet.de>

// This file is part of Yoltia.
//
// Yoltia is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License Version 2
// as published by the Free Software Foundation.
//    
// Yoltia is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Yoltia; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA

#include "sins.hpp"
#include <qpushbutton.h>
#include <qlayout.h>
#include <qapplication.h>
#include <qclipboard.h>

SIns::SIns(QWidget *parent , QImage *dataAddr , QImage *backupAddr) : QDialog(parent , "ins" , true) {
  data = dataAddr;
  backup = backupAddr;
  clip = QApplication::clipboard()->image(QClipboard::Clipboard).copy();
  QGridLayout *container = new QGridLayout(this , 0 , 0 , 10 , -1 , "container");
  QSizePolicy sizePolicy(QSizePolicy::MinimumExpanding , QSizePolicy::Fixed);
  x = new QSpinBox(0 , 8200 - data->width() , 1 , this , "x");
  y = new QSpinBox(0 , 8200 - data->width() , 1 , this , "y");
  x->setSizePolicy(sizePolicy);
  y->setSizePolicy(sizePolicy);
  x->setSuffix(" Pixel");
  y->setSuffix(" Pixel");
  connect(x , SIGNAL(valueChanged(int)) , this , SLOT(createPreview()));
  connect(y , SIGNAL(valueChanged(int)) , this , SLOT(createPreview()));
  container->addWidget(new QLabel(x , "&X:" , this , "descrX") , 0 , 0);
  container->addWidget(new QLabel(y , "&Y:" , this , "descrY") , 1 , 0);
  container->addWidget(x , 0 , 1);
  container->addWidget(y , 1 , 1);
  sizeChanger = new SCSizeChanger(clip.width() , clip.height() , this);
  resize = new QCheckBox(tr("&Enlarge picture if necessary") , this , "resize");
  resize->setChecked(true);
  connect(sizeChanger , SIGNAL(sizeChanged()) , this , SLOT(createPreview()));
  connect(resize , SIGNAL(clicked()) , this , SLOT(createPreview()));
  container->addMultiCellWidget(sizeChanger , 2 , 2 , 0 , 1);
  container->addMultiCellWidget(resize , 3 , 3 , 0 , 1);
  QPushButton *fertig = new QPushButton(tr("&Finished") , this , "fertig");
  fertig->setDefault(true);
  connect(fertig , SIGNAL(clicked()) , this , SLOT(accept()));
  container->addMultiCellWidget(fertig , 4 , 4 , 0 , 1);
  setCaption(tr("Insert"));
  createPreview();
}

void SIns::createPreview() {
  x->setRange(0 , 8200 - sizeChanger->getWidth());
  y->setRange(0 , 8200 - sizeChanger->getHeight());
  QImage temp(clip.scale(sizeChanger->getWidth() , sizeChanger->getHeight()));
  if (resize->isChecked())	//Bild wenn n�tig vergr��ern?
      *data = backup->copy(0 , 0 , QMAX(temp.width() + x->value() , backup->width()) , QMAX(temp.height() + y->value() , backup->height()));
    else {	//Bild nicht vergr��ern, sondern Clip zuschneiden
      *data = backup->copy();
      temp = temp.copy(0 , 0 , QMIN(temp.width() , backup->width() - x->value()) , QMIN(temp.height() , backup->height() - y->value()));
  }
  for (int itX = 0 ; itX < temp.width() ; itX++)	//Iterator-X
    for (int itY = 0 ; itY < temp.height() ; itY++)	//Iterator-Y
      data->setPixel(itX + x->value() , itY + y->value() , temp.pixel(itX , itY));
  emit modified();
}
