// Copyright (C) 2005-2007 Stefan Bauer <yoltia-maintain@freenet.de>

// This file is part of Yoltia.
//
// Yoltia is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License Version 2
// as published by the Free Software Foundation.
//    
// Yoltia is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Yoltia; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA

#include "ssize.hpp"
#include <qpushbutton.h>
#include <qlayout.h>

SSize::SSize(QWidget *parent , QImage *dataAddr , QImage *backupAddr) : QDialog(parent , "size" , true) {
  data = dataAddr;
  backup = backupAddr;
  QVBoxLayout *mainContainer = new QVBoxLayout(this , 10 , -1 , "mainContainer");
  sizeChanger = new SCSizeChanger(backup->width() , backup->height() , this);
  connect(sizeChanger , SIGNAL(sizeChanged()) , this , SLOT(createPreview()));
  stretch = new QCheckBox(tr("&Tug picture") , this , "stretch");
  mainContainer->addWidget(sizeChanger);
  mainContainer->addWidget(stretch);
  vAlign = new QListBox(this , "vAlign");
  hAlign = new QListBox(this , "hAlign");
  vAlign->insertStringList(QStringList::split("-" , tr("Up-Center-Down")));
  hAlign->insertStringList(QStringList::split("-" , tr("Left-Center-Right")));
  vAlign->setCurrentItem(0);
  hAlign->setCurrentItem(0);
  QLabel *descrVAlign = new QLabel(vAlign , tr("&Vertical alignment:") , this , "decrVAlign");
  QLabel *descrHAlign = new QLabel(hAlign , tr("&Horizontal alignment:") , this , "descrHAlign");
  connect(stretch , SIGNAL(toggled(bool)) , descrVAlign , SLOT(setDisabled(bool)));
  connect(stretch , SIGNAL(toggled(bool)) , descrHAlign , SLOT(setDisabled(bool)));
  connect(stretch , SIGNAL(toggled(bool)) , vAlign , SLOT(setDisabled(bool)));
  connect(stretch , SIGNAL(toggled(bool)) , hAlign , SLOT(setDisabled(bool)));
  connect(stretch , SIGNAL(clicked()) , this , SLOT(createPreview()));
  connect(vAlign , SIGNAL(selectionChanged()) , this , SLOT(createPreview()));
  connect(hAlign , SIGNAL(selectionChanged()) , this , SLOT(createPreview()));
  QGridLayout *gridContainer = new QGridLayout(mainContainer , 2 , 2 , 10 , "gridContainer");
  gridContainer->addWidget(descrVAlign , 0 , 0);
  gridContainer->addWidget(descrHAlign , 0 , 1);
  gridContainer->addWidget(vAlign , 1 , 0);
  gridContainer->addWidget(hAlign , 1 , 1);
  QPushButton *ok = new QPushButton(tr("&Finished") , this , "ok");
  ok->setDefault(true);
  connect(ok , SIGNAL(clicked()) , this , SLOT(accept()));
  mainContainer->addWidget(ok);
  setCaption(tr("Resize"));
}

void SSize::createPreview() {
  if (stretch->isChecked())
      *data = backup->smoothScale(sizeChanger->getWidth() , sizeChanger->getHeight());
    else {
      int x , y;
      switch (hAlign->currentItem()) {
	case 1 :	//Zentriert
	  x = qRound((backup->width() - sizeChanger->getWidth()) / 2.0);
	  break;
	case 2 :	//Rechts
	  x = backup->width() - sizeChanger->getWidth();
	  break;
	default :	//Links
	  x = 0;
      }
      switch (vAlign->currentItem()) {
	case 1 :	//Zentriert
	  y = qRound((backup->height() - sizeChanger->getHeight()) / 2.0);
	  break;
	case 2 :	//Unten
	  y = backup->height() - sizeChanger->getHeight();
	  break;
	default :	//Oben
	  y = 0;
      }
      *data = backup->copy(x , y , sizeChanger->getWidth() , sizeChanger->getHeight());
  }
  emit modified();
}
